@@ -4,13 +4,15 @@ from dataclasses import dataclass
 from typing import Any, Callable, Dict, Optional
 
 from google.protobuf.json_format import MessageToDict
+from pyspark.sql import SparkSession
 
 from flytekit import FlyteContextManager, PythonFunctionTask
 from flytekit.common.tasks.sdk_runnable import ExecutionParameters
 from flytekit.extend import ExecutionState, SerializationSettings, TaskPlugins
-from flytekit.models import task as _task_model
 from flytekit.sdk.spark_types import SparkType
 
+from .models import SparkJob
+
 
 @dataclass
 class Spark(object):
@@ -87,10 +89,10 @@ class PysparkFunctionTask(PythonFunctionTask[Spark]):
             task_function=task_function,
             **kwargs,
         )
-        self.sess = None
+        self.sess: Optional[SparkSession] = None
 
     def get_custom(self, settings: SerializationSettings) -> Dict[str, Any]:
-        job = _task_model.SparkJob(
+        job = SparkJob(
             spark_conf=self.task_config.spark_conf,
             hadoop_conf=self.task_config.hadoop_conf,
             application_file="local://" + settings.entrypoint_settings.path if settings.entrypoint_settings else "",
